// case - file manager for N900
// Copyright (C) 2010 Lukas Hrazky <lukkash@email.cz>
// 
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <http://www.gnu.org/licenses/>.


#ifndef PANE_H
#define PANE_H

#include <QFileInfoList>
#include <QDir>

#include "button.h"
#include "filelist.h"
#include "addressbar.h"


class Pane : public QWidget {
    Q_OBJECT

signals:
    void switchPanes();

public:
    bool active;

    explicit Pane(QWidget *theCase, QWidget *parent = 0);

    const QString path() const;
    const QFileInfoList selection() const;

public slots:
    bool changePath(QString path);
    void toggleActive();
    void toggleShowHiddenFiles();
    void fileListMouseHackaround();

protected:
    void paintEvent(QPaintEvent *);

    bool eventFilter(QObject *object, QEvent *event);

private:
    QWidget *theCase;

    AddressBar *location;
    Button *up;
    FileList *fileList;
};

#endif // PANE_H
